@@ -27,28 +27,96 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataJs.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataJs.php,v 1.4 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ꥯȥǡݻ饹
- */
-require_once 'SyL_DataWeb.php';
-
-/**
- * JavaScriptꥯȥǡݻ饹
+ * JavaScriptǡݻ饹
  * 
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataJs.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataJs.php,v 1.4 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_DataJs extends SyL_DataWeb
+class SyL_DataJs extends SyL_Data
 {
+    /**
+     * JavaScriptϾ
+     * 
+     * @access private
+     * @var string
+     */
+    var $javascript = '';
+    /**
+     * JavaScriptϥ饹
+     * 
+     * @access private
+     * @var array
+     */
+    var $imports = array();
+    /**
+     * ݡȥѥ᡼̾
+     *
+     * @access private
+     * @var string
+     */
+    var $import_parameter = 'import';
+    /**
+     * ݡȥեΥѥ졼
+     *
+     * @access private
+     * @var string
+     */
+    var $separater = ',';
+
+    /**
+     * ϥ饹ɲ
+     * 
+     * @access public
+     * @param string ϥ饹
+     */
+    function addImport($import)
+    {
+        $this->imports = array_merge($this->imports, $import);
+    }
+
+    /**
+     * ϥ饹
+     * 
+     * @access public
+     * @return array ϥ饹
+     */
+    function getImport()
+    {
+        return $this->imports;
+    }
+
+    /**
+     * JavaScriptϾ򥻥å
+     * 
+     * @access public
+     * @param string JavaScriptϾ
+     */
+    function setJs($javascript)
+    {
+        $this->javascript = $javascript;
+    }
+
+    /**
+     * JavaScriptϾ
+     * 
+     * @access public
+     * @return string JavaScriptϾ
+     */
+    function getJs()
+    {
+        return $this->javascript;
+    }
+
     /**
      * ϥѥ᡼򥻥å
      * 
@@ -68,6 +136,12 @@ class SyL_DataJs extends SyL_DataWeb
         if (function_exists('mb_check_encoding')) {
             $this->applyCheckEncodingRecursive($this->input_parameters, SYL_ENCODE_INTERNAL);
         }
+
+        // ꥤݡȥѥ᡼ɲ
+        $js = $this->get($this->import_parameter);
+        if (is_string($js)) {
+            $this->imports = array_merge($this->imports, explode($this->separater, $js));
+        }
     }
 
     /**
