@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.8 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.9 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,34 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.8 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.9 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorJs extends SyL_Error
 {
+    /**
+     * 404 Not Found ɽ
+     *
+     * @access public
+     */
+    function forward404Detail()
+    {
+        SyL_Loggers::notice("404 Not Found");
+
+        $error_message = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
+        if (isset($_SERVER['REQUEST_METHOD']) && ($_SERVER['REQUEST_METHOD'] == 'POST')) {
+            // JSON
+            SyL_Response::setStatusHeader('404');
+        } else {
+            // JavaScript
+            $error_message = str_replace("'", "\\'", $error_message);
+            $error_message = "alert('{$error_message}');";
+        }
+
+        echo $error_message;
+        exit;
+    }
+
     /**
      * Ķ̥顼
      * 
@@ -59,13 +82,22 @@ class SyL_ErrorJs extends SyL_Error
             $error_message = implode($this->eol, $error_messages);
         }
 
-        SyL_Response::setStatusHeader('500');
-        $content_type = 'application/x-javascript; charset=' . SYL_ENCODE_INTERNAL;
-
         // JavaScirptƥĥ
+        $content_type = 'application/x-javascript; charset=' . SYL_ENCODE_INTERNAL;
         SyL_Response::setHeader('Content-Type', $content_type);
-        $response =& SyL_Response::singleton();
-        $response->display($error_message);
+        if ($error_message !== '') {
+            if (isset($_SERVER['REQUEST_METHOD']) && ($_SERVER['REQUEST_METHOD'] == 'POST')) {
+                // JSON
+                SyL_Response::setStatusHeader('500');
+            } else {
+                // JavaScript
+                $error_message = str_replace("'", "\\'", $error_message);
+                $error_message = str_replace($this->eol, "\\n", $error_message);
+                $error_message = "alert('{$error_message}');";
+            }
+            $response =& SyL_Response::singleton();
+            $response->display($error_message);
+        }
     }
 
     /**
