@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.11 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.12 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.11 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.12 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJson extends SyL_View
@@ -58,12 +58,8 @@ class SyL_ViewJson extends SyL_View
         // ѥ᡼ϡJson֥Ȥ򥻥å
         if (!function_exists('json_encode')) {
             include_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilJson.php';
-            $javascript = json_encode($values);
-        } else {
-            mb_convert_variables(SYL_ENCODE_JS, SYL_ENCODE_INTERNAL, $values);
-            $javascript = json_encode($values);
-            $javascript = mb_convert_encoding($javascript, SYL_ENCODE_INTERNAL, SYL_ENCODE_JS);
         }
+        $javascript = json_encode($values);
         // JavaScirpt
         $this->setRender($javascript);
     }
