@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Socket.php,v 1.10 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Socket.php,v 1.12 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,10 @@
  *  åȥ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Socket.php,v 1.10 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Socket.php,v 1.12 2008/01/20 15:09:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Socket
@@ -65,7 +65,7 @@ class SyL_Socket
      * @var string
      */
     var $response = '';
-  
+
     /**
      * 顼No
      * 
@@ -162,7 +162,7 @@ class SyL_Socket
      * @param int ॢ
      * @return true: ³OK, false: ³NG
      */
-    function open($timeout=3)
+    function open($timeout=3, $blocking=true)
     {
         $this->conn = fsockopen($this->host, $this->port, $this->error_no, $this->error_string, $timeout);
         if (!$this->isSocket()) {
@@ -175,12 +175,11 @@ class SyL_Socket
             return false;
         }
         // ֥å󥰥⡼
-        if (!stream_set_blocking($this->conn, 1)) {
+        if (!stream_set_blocking($this->conn, ($blocking ? 1 : 0))) {
             $this->error_no = 1;
             $this->error_string = "stream_set_blocking setting error";
             return false;
         }
-
         return true;
     }
 
